PYGYRE
======

This project provides Python support for the GYRE oscillation code suite. 
PYGYRE is free software: you can redistribute it and/or modify it under 
the terms of the GNU General Public License as published by the Free 
Software Foundation, version 3. See the file COPYING for further details.

Full documentation for PYGYRE can be found on this website:

https://pygyre.readthedocs.io/en/latest/
